scale_type.distribution: Sets scale for distributions
Description
Generates a single value from the distribution and uses it to set the default ggplot scale. The scale can be changed later in the ggplot by using any scale_* function
Usage
# S3 method for distribution
scale_type(x)
Value
A character vector of scale types. The scale type is the ggplot
scale type of the outcome of the distribution.
Arguments
- x
value being scaled