Learn R Programming

ggdibbler (version 0.6.1)

toy_temp_dist: A toy data set that provides data for a map with the temperature of each area represented by a random variable.

Description

The map shows a wave pattern in temperature on the state of Iowa. Each estimate also has an uncertainty component added, and is represented as a distribution

Arguments

Format

A tibble with 99 observations and 4 variables

county_name

the name of each Iowa county

temp_dist

the temperature of each county as a distribution

county_geometry

the shape file for each county of Iowa