This dataset is identical to the economics data, except that every variable in the data set is represented by a normal random variable. The original `economics` dataset is based on real US economic time series data, but the uncertainty we added is hypothetical and included for illustrative purposes.
uncertain_economics_longA data frame with almost 574 observations and 6 variables:
A deterministic variable - Month of data collection
Normal random variable - personal consumption expenditures, in billions of dollars
Normal random variable - total population, in thousands
Normal random variable - personal savings rate
Normal random variable - median duration of unemployment, in weeks
Normal random variable - number of unemployed in thousands
An object of class tbl_df (inherits from tbl, data.frame) with 2870 rows and 4 columns.