A 2d density estimate of the waiting and eruptions variables data faithful. Unlike other uncertain datasets, the only uncertain variable is density. Since this is based on a model, it wouldn't make sense for erruptions or waiting to be represented as random variables.
A data frame with 5,625 observations and 3 variables:
Eruption time in mins
Waiting time to next eruption in mins
A 2d density estimate that is normally distributed with a low variance
A 2d density estimate that is normally distributed with a medium variance
A 2d density estimate that is normally distributed with a high variance