This dataset is identical to the mtcars data, except that every variable in the data set is represented by a categorical, discrete, or continuous random variable. The original `mtcars` dataset in datasets is based on real data extracted from the 1974 Motor Trend US magazine, but the uncertainty we added is hypothetical and included for illustrative purposes.
A data frame with 32 observations and 11 variables:
Uniform random variable - Miles/(US) gallon as
Categorical random variable - Number of cylinders
Uniform random variable - Displacement (cu.in.)
Normal random variable - Gross horsepower
Uniform random variable - Rear axle ratio
Uniform random variable - Weight (1000 lbs)
Uniform random variable - 1/4 mile time
Bernouli random variable - Engine (0 = V-shaped, 1 = straight)
Bernouli random variable - Transmission (0 = automatic, 1 = manual)
Categorical random variable - Number of forward gears
Categorical random variable- Number of carburetors