The map shows a wave pattern in temperature on the state of Iowa. Each estimate also has an uncertainty component added, and is represented as a distribution
A tibble with 99 observations and 4 variables
the name of each Iowa county
the temperature of each county as a distribution
the shape file for each county of Iowa